#[non_exhaustive]pub enum HashingError {
Operation {
operation: HashingOperation,
message: String,
algorithm: Option<String>,
expected_format: Option<String>,
},
}Expand description
Error returned by hashing services and verification flows.
Use this type when hashing or verification cannot be completed safely.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Operation
A hashing-related operation failed.
Implementations
Sourceimpl HashingError
impl HashingError
Sourcepub fn new(operation: HashingOperation, message: impl Into<String>) -> Self
pub fn new(operation: HashingOperation, message: impl Into<String>) -> Self
Creates a hashing error without algorithm or format context.
Examples
use webgates_secrets::hashing::errors::{HashingError, HashingOperation};
let _err = HashingError::new(HashingOperation::Hash, "failed to hash value");Sourcepub fn with_algorithm(
operation: HashingOperation,
message: impl Into<String>,
algorithm: impl Into<String>,
) -> Self
pub fn with_algorithm( operation: HashingOperation, message: impl Into<String>, algorithm: impl Into<String>, ) -> Self
Creates a hashing error with algorithm context.
Examples
use webgates_secrets::hashing::errors::{HashingError, HashingOperation};
let _err = HashingError::with_algorithm(HashingOperation::Verify, "verification failed", "argon2id");Sourcepub fn with_context(
operation: HashingOperation,
message: impl Into<String>,
algorithm: Option<String>,
expected_format: Option<String>,
) -> Self
pub fn with_context( operation: HashingOperation, message: impl Into<String>, algorithm: Option<String>, expected_format: Option<String>, ) -> Self
Creates a hashing error with full context.
Examples
use webgates_secrets::hashing::errors::{HashingError, HashingOperation};
let _err = HashingError::with_context(
HashingOperation::Verify,
"verification failed",
Some("argon2id".into()),
Some("$argon2id$v=19$...".into()),
);Trait Implementations
Sourceimpl Debug for HashingError
impl Debug for HashingError
Sourceimpl Display for HashingError
impl Display for HashingError
Sourceimpl Error for HashingError
impl Error for HashingError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl UserFriendlyError for HashingError
impl UserFriendlyError for HashingError
Sourcefn user_message(&self) -> String
fn user_message(&self) -> String
User-facing message that is clear, actionable, and non-technical. Read more
Sourcefn developer_message(&self) -> String
fn developer_message(&self) -> String
Technical message with detailed information for developers and logs. Read more
Sourcefn support_code(&self) -> String
fn support_code(&self) -> String
Unique support reference code for customer service and troubleshooting. Read more
Sourcefn severity(&self) -> ErrorSeverity
fn severity(&self) -> ErrorSeverity
Error severity level for proper handling and alerting.
Sourcefn suggested_actions(&self) -> Vec<String>
fn suggested_actions(&self) -> Vec<String>
Suggested user actions for resolving the error (optional).
Sourcefn is_retryable(&self) -> bool
fn is_retryable(&self) -> bool
Whether this error should be retryable by the user (default: false).